@@ -3,17 +3,23 @@ import functools
 import multiprocessing
 import platform
 import random
+import subprocess
 import time
 import webbrowser
 
-import keyboard as kb
 import pyautogui
 import pyperclip
 from PIL import Image
 
 from botcity.base import BaseBot, State
 from botcity.base.utils import is_retina, only_if_element
-from . import config
+from . import config, os_compat
+
+try:
+    from botcity.maestro import BotMaestroSDK
+    MAESTRO_AVAILABLE = True
+except ImportError:
+    MAESTRO_AVAILABLE = False
 
 
 class DesktopBot(BaseBot):
@@ -30,7 +36,7 @@ class DesktopBot(BaseBot):
     def __init__(self):
         super().__init__()
         self.state = State()
-        self.maestro = None
+        self.maestro = BotMaestroSDK() if MAESTRO_AVAILABLE else None
 
         # For parity with Java
         self.addImage = self.add_image
@@ -268,6 +274,92 @@ class DesktopBot(BaseBot):
                 self.state.element = ele
                 return ele
 
+    def find_all(self, label, x=None, y=None, width=None, height=None, *,
+                 threshold=None, matching=0.9, waiting_time=10000, grayscale=False):
+        """
+        Find all elements defined by label on screen until a timeout happens.
+
+        Args:
+            label (str): The image identifier
+            x (int, optional): Search region start position x. Defaults to 0.
+            y (int, optional): Search region start position y. Defaults to 0.
+            width (int, optional): Search region width. Defaults to screen width.
+            height (int, optional): Search region height. Defaults to screen height.
+            threshold (int, optional): The threshold to be applied when doing grayscale search.
+                Defaults to None.
+            matching (float, optional): The matching index ranging from 0 to 1.
+                Defaults to 0.9.
+            waiting_time (int, optional): Maximum wait time (ms) to search for a hit.
+                Defaults to 10000ms (10s).
+            grayscale (bool, optional): Whether or not to convert to grayscale before searching.
+                Defaults to False.
+
+        Returns:
+            elements (collections.Iterable[NamedTuple]): A generator with all element coordinates fount.
+                None if not found.
+        """
+        def deduplicate(elems):
+            def find_same(item, items):
+                x_start = item.left
+                x_end = item.left + item.width
+                y_start = item.top
+                y_end = item.top + item.height
+                similars = []
+                for itm in items:
+                    if itm == item:
+                        continue
+                    if (itm.left >= x_start and itm.left <= x_end)\
+                            and (itm.top >= y_start and itm.top <= y_end):
+                        similars.append(itm)
+                        continue
+                return similars
+
+            index = 0
+            while True:
+                try:
+                    dups = find_same(elems[index], elems[index:])
+                    for d in dups:
+                        elems.remove(d)
+                    index += 1
+                except IndexError:
+                    break
+            return elems
+
+        self.state.element = None
+        screen_w, screen_h = pyautogui.size()
+        x = x or 0
+        y = y or 0
+        w = width or screen_w
+        h = height or screen_h
+
+        region = (x, y, w, h)
+
+        element_path = self._search_image_file(label)
+
+        if threshold:
+            # TODO: Figure out how we should do threshold
+            print('Threshold not yet supported')
+
+        start_time = time.time()
+
+        while True:
+            elapsed_time = (time.time() - start_time) * 1000
+            if elapsed_time > waiting_time:
+                return None
+
+            eles = pyautogui.locateAllOnScreen(element_path, region=region, confidence=matching,
+                                               grayscale=grayscale)
+            if not eles:
+                continue
+            eles = deduplicate(list(eles))
+            for ele in eles:
+                if ele is not None:
+                    if is_retina():
+                        ele = ele._replace(left=ele.left / 2.0, top=ele.top / 2.0)
+                    self.state.element = ele
+                    yield ele
+            break
+
     def find_text(self, label, x=None, y=None, width=None, height=None, *, threshold=None, matching=0.9,
                   waiting_time=10000, best=True):
         """
@@ -462,7 +554,7 @@ class DesktopBot(BaseBot):
             label (str): The image identifier
         """
         x, y = self.get_element_coords_centered(label)
-        pyautogui.click(x, y)
+        os_compat.click(x, y)
 
     def get_last_x(self):
         """
@@ -501,7 +593,7 @@ class DesktopBot(BaseBot):
             x (int): The X coordinate
             y (int): The Y coordinate
         """
-        pyautogui.click(x, y)
+        os_compat.click(x, y)
 
     @only_if_element
     def click(self, wait_after=config.DEFAULT_SLEEP_AFTER_ACTION, *,
@@ -516,7 +608,7 @@ class DesktopBot(BaseBot):
             button (str, optional): One of 'left', 'right', 'middle'. Defaults to 'left'
         """
         x, y = self.state.center()
-        pyautogui.click(x, y, clicks=clicks, button=button, interval=interval_between_clicks)
+        os_compat.click(x, y, clicks=clicks, button=button, interval=interval_between_clicks/1000.0)
         self.sleep(wait_after)
 
     @only_if_element
@@ -535,7 +627,7 @@ class DesktopBot(BaseBot):
         """
         x = self.state.x() + x
         y = self.state.y() + y
-        pyautogui.click(x, y, clicks=clicks, button=button, interval=interval_between_clicks)
+        os_compat.click(x, y, clicks=clicks, button=button, interval=interval_between_clicks/1000.0)
         self.sleep(wait_after)
 
     @only_if_element
@@ -546,8 +638,7 @@ class DesktopBot(BaseBot):
         Args:
             wait_after (int, optional): Interval to wait after clicking on the element.
         """
-        x, y = self.state.center()
-        self.click(x, y, wait_after=wait_after, clicks=2)
+        self.click(wait_after=wait_after, clicks=2)
 
     @only_if_element
     def double_click_relative(self, x, y, interval_between_clicks=0, wait_after=config.DEFAULT_SLEEP_AFTER_ACTION):
@@ -561,8 +652,6 @@ class DesktopBot(BaseBot):
             wait_after (int, optional): Interval to wait after clicking on the element.
 
         """
-        x = self.state.x() + x
-        y = self.state.y() + y
         self.click_relative(x, y, wait_after=wait_after, clicks=2, interval_between_clicks=interval_between_clicks)
 
     @only_if_element
@@ -573,8 +662,7 @@ class DesktopBot(BaseBot):
         Args:
             wait_after (int, optional): Interval to wait after clicking on the element.
         """
-        x, y = self.state.center()
-        self.click(x, y, wait_after=wait_after, clicks=3)
+        self.click(wait_after=wait_after, clicks=3)
 
     @only_if_element
     def triple_click_relative(self, x, y, interval_between_clicks=0, wait_after=config.DEFAULT_SLEEP_AFTER_ACTION):
@@ -588,10 +676,30 @@ class DesktopBot(BaseBot):
             wait_after (int, optional): Interval to wait after clicking on the element.
 
         """
-        x = self.state.x() + x
-        y = self.state.y() + y
         self.click_relative(x, y, wait_after=wait_after, clicks=3, interval_between_clicks=interval_between_clicks)
 
+    def mouse_down(self, wait_after=config.DEFAULT_SLEEP_AFTER_ACTION, *, button='left'):
+        """
+        Holds down the requested mouse button.
+
+        Args:
+            wait_after (int, optional): Interval to wait after clicking on the element.
+            button (str, optional): One of 'left', 'right', 'middle'. Defaults to 'left'
+        """
+        pyautogui.mouseDown(button=button)
+        self.sleep(wait_after)
+
+    def mouse_up(self, wait_after=config.DEFAULT_SLEEP_AFTER_ACTION, *, button='left'):
+        """
+        Releases the requested mouse button.
+
+        Args:
+            wait_after (int, optional): Interval to wait after clicking on the element.
+            button (str, optional): One of 'left', 'right', 'middle'. Defaults to 'left'
+        """
+        pyautogui.mouseUp(button=button)
+        self.sleep(wait_after)
+
     def scroll_down(self, clicks):
         """
         Scroll Down n clicks
@@ -656,7 +764,7 @@ class DesktopBot(BaseBot):
             interval_between_clicks (int, optional): The interval between clicks in ms. Defaults to 0.
         """
         x, y = self.state.center()
-        pyautogui.click(x, y, clicks=clicks, button='right', interval=interval_between_clicks)
+        os_compat.click(x, y, clicks=clicks, button='right', interval=interval_between_clicks/1000.0)
         self.sleep(wait_after)
 
     def right_click_at(self, x, y):
@@ -667,7 +775,7 @@ class DesktopBot(BaseBot):
             x (int): The X coordinate
             y (int): The Y coordinate
         """
-        pyautogui.click(x, y, button='right')
+        os_compat.click(x, y, button='right')
 
     @only_if_element
     def right_click_relative(self, x, y, interval_between_clicks=0, wait_after=config.DEFAULT_SLEEP_AFTER_ACTION):
@@ -698,7 +806,7 @@ class DesktopBot(BaseBot):
             interval (int, optional): interval (ms) between each key press. Defaults to 0
 
         """
-        self.kb_type(text=text, interval=interval)
+        self.kb_type(text=text, interval=interval/1000.0)
 
     def kb_type(self, text, interval=0):
         """
@@ -709,7 +817,7 @@ class DesktopBot(BaseBot):
             interval (int, optional): interval (ms) between each key press. Defaults to 0
 
         """
-        kb.write(text, delay=interval / 1000.0)
+        pyautogui.write(text, interval=interval/1000.0)
         self.sleep(config.DEFAULT_SLEEP_AFTER_ACTION)
 
     def paste(self, text=None, wait=0):
@@ -747,7 +855,7 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('tab')
+        pyautogui.press('tab')
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -759,7 +867,7 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('enter')
+        pyautogui.press('enter')
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -771,13 +879,13 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('right')
+        pyautogui.press('right')
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
     def key_enter(self, wait=0):
         """
-        Press key Right
+        Press key Enter
 
         Args:
             wait (int, optional): Wait interval (ms) after task
@@ -793,7 +901,7 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('end')
+        pyautogui.press('end')
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -805,20 +913,20 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('esc')
+        pyautogui.press('esc')
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
     def _key_fx(self, idx, wait=0):
         """
-        Press key Fidx where idx is a value from 1 to 12
+        Press key F[idx] where idx is a value from 1 to 12
 
         Args:
             idx (int): F key index from 1 to 12
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send(f'F{idx}')
+        pyautogui.press(f'f{idx}')
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -866,7 +974,7 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.press('shift')
+        pyautogui.keyDown('shift')
         self.sleep(wait)
 
     def release_shift(self):
@@ -874,7 +982,7 @@ class DesktopBot(BaseBot):
         Release key Shift.
         This method needs to be invoked after holding Shift or similar.
         """
-        kb.release('shift')
+        pyautogui.keyUp('shift')
 
     def alt_space(self, wait=0):
         """
@@ -884,7 +992,7 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('alt+space')
+        pyautogui.hotkey('alt', 'space', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -894,7 +1002,7 @@ class DesktopBot(BaseBot):
         """
         self.alt_space()
         self.sleep(1000)
-        kb.send('x')
+        pyautogui.press('x')
 
     def type_keys_with_interval(self, interval, keys):
         """
@@ -904,13 +1012,7 @@ class DesktopBot(BaseBot):
             interval (int): Interval (ms) in which to press and release keys
             keys (list): List of keys to be pressed
         """
-        for k in keys:
-            kb.press(k)
-            self.sleep(interval)
-
-        for k in keys.reverse():
-            kb.release(k)
-            self.sleep(interval)
+        pyautogui.hotkey(*keys, interval=interval/1000.0)
 
     def type_keys(self, keys):
         """
@@ -929,7 +1031,7 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('alt+e')
+        pyautogui.hotkey('alt', 'e', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -941,7 +1043,7 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('alt+r')
+        pyautogui.hotkey('alt', 'r', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -953,7 +1055,7 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('alt+f')
+        pyautogui.hotkey('alt', 'f', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -965,7 +1067,7 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('alt+u')
+        pyautogui.hotkey('alt', 'u', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -977,7 +1079,7 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('alt+f4')
+        pyautogui.hotkey('alt', 'f4', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -992,9 +1094,10 @@ class DesktopBot(BaseBot):
         key = 'ctrl'
         if platform.system() == 'Darwin':
             key = 'command'
-        kb.send(f'{key}+c')
+        pyautogui.hotkey(key, 'c', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
+        return self.get_clipboard()
 
     def control_v(self, wait=0):
         """
@@ -1007,7 +1110,7 @@ class DesktopBot(BaseBot):
         key = 'ctrl'
         if platform.system() == 'Darwin':
             key = 'command'
-        kb.send(f'{key}+v')
+        pyautogui.hotkey(key, 'v', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1022,7 +1125,7 @@ class DesktopBot(BaseBot):
         key = 'ctrl'
         if platform.system() == 'Darwin':
             key = 'command'
-        kb.send(f'{key}+a')
+        pyautogui.hotkey(key, 'a', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1037,7 +1140,7 @@ class DesktopBot(BaseBot):
         key = 'ctrl'
         if platform.system() == 'Darwin':
             key = 'command'
-        kb.send(f'{key}+f')
+        pyautogui.hotkey(key, 'f', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1052,7 +1155,7 @@ class DesktopBot(BaseBot):
         key = 'ctrl'
         if platform.system() == 'Darwin':
             key = 'command'
-        kb.send(f'{key}+p')
+        pyautogui.hotkey(key, 'p', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1067,7 +1170,7 @@ class DesktopBot(BaseBot):
         key = 'ctrl'
         if platform.system() == 'Darwin':
             key = 'command'
-        kb.send(f'{key}+u')
+        pyautogui.hotkey(key, 'u', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1082,7 +1185,7 @@ class DesktopBot(BaseBot):
         key = 'ctrl'
         if platform.system() == 'Darwin':
             key = 'command'
-        kb.send(f'{key}+r')
+        pyautogui.hotkey(key, 'r', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1097,7 +1200,7 @@ class DesktopBot(BaseBot):
         key = 'ctrl'
         if platform.system() == 'Darwin':
             key = 'command'
-        kb.send(f'{key}+t')
+        pyautogui.hotkey(key, 't', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1112,7 +1215,7 @@ class DesktopBot(BaseBot):
         key = 'ctrl'
         if platform.system() == 'Darwin':
             key = 'command'
-        kb.send(f'{key}+end')
+        pyautogui.hotkey(key, 'end', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1127,7 +1230,7 @@ class DesktopBot(BaseBot):
         key = 'ctrl'
         if platform.system() == 'Darwin':
             key = 'command'
-        kb.send(f'{key}+home')
+        pyautogui.hotkey(key, 'home', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1142,7 +1245,7 @@ class DesktopBot(BaseBot):
         key = 'ctrl'
         if platform.system() == 'Darwin':
             key = 'command'
-        kb.send(f'{key}+w')
+        pyautogui.hotkey(key, 'w', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1157,7 +1260,7 @@ class DesktopBot(BaseBot):
         key = 'ctrl'
         if platform.system() == 'Darwin':
             key = 'command'
-        kb.send(f'{key}+shift+p')
+        pyautogui.hotkey(key, 'shift', 'p', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1172,7 +1275,7 @@ class DesktopBot(BaseBot):
         key = 'ctrl'
         if platform.system() == 'Darwin':
             key = 'command'
-        kb.send(f'{key}+shift+j')
+        pyautogui.hotkey(key, 'shift', 'j', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1184,7 +1287,7 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('shift+tab')
+        pyautogui.hotkey('shift', 'tab', interval=0.25)
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1205,7 +1308,7 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('left')
+        pyautogui.press('left')
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1217,7 +1320,7 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('right')
+        pyautogui.press('right')
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1229,7 +1332,7 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('down')
+        pyautogui.press('down')
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1241,7 +1344,7 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('up')
+        pyautogui.press('up')
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1253,7 +1356,31 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('windows')
+        pyautogui.press('win')
+        delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
+        self.sleep(delay)
+
+    def page_up(self, wait=0):
+        """
+        Press Page Up key
+
+        Args:
+            wait (int, optional): Wait interval (ms) after task
+
+        """
+        pyautogui.press('pageup')
+        delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
+        self.sleep(delay)
+
+    def page_down(self, wait=0):
+        """
+        Press Page Down key
+
+        Args:
+            wait (int, optional): Wait interval (ms) after task
+
+        """
+        pyautogui.press('pagedown')
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1265,7 +1392,7 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('space')
+        pyautogui.press('space')
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1277,7 +1404,7 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('backspace')
+        pyautogui.press('backspace')
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
@@ -1289,13 +1416,35 @@ class DesktopBot(BaseBot):
             wait (int, optional): Wait interval (ms) after task
 
         """
-        kb.send('del')
+        pyautogui.press('delete')
         delay = max(0, wait or config.DEFAULT_SLEEP_AFTER_ACTION)
         self.sleep(delay)
 
-    ##########
-    # Keyboard
-    ##########
+    ######
+    # Misc
+    ######
+
+    def wait_for_file(self, path, timeout=10000):
+        """
+        Invoke the system handler to open the given file.
+
+        Args:
+            path (str): The path for the file to be executed
+            timeout (int, optional): Maximum wait time (ms) to search for a hit.
+                Defaults to 10000ms (10s).
+
+        Returns
+            status (bool): Whether or not the file was available before the timeout
+        """
+        start_time = time.time()
+
+        while True:
+            elapsed_time = (time.time() - start_time) * 1000
+            if elapsed_time > timeout:
+                return False
+            if os.path.isfile(path) and os.access(path, os.R_OK):
+                return True
+            self.sleep(config.DEFAULT_SLEEP_AFTER_ACTION)
 
     def execute(self, file_path):
         """
@@ -1304,7 +1453,10 @@ class DesktopBot(BaseBot):
         Args:
             file_path (str): The path for the file to be executed
         """
-        os.startfile(file_path)
+        if platform.system() == "Windows":
+            os.startfile(file_path)
+        else:
+            subprocess.Popen(file_path.split(" "))
 
     def wait(self, interval):
         """
